/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 
         International, see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.
--------------------------------------------------------------------------------

This is an example of how to analyse data generated by the randomtest.C macro

Common usage in the ROOT command line would be, e.g.:

root [0] .x tgng_load.C
root [3] .L analysetest.C
root [4] analyse_gng("output");

*/

void analyse_gng(const char *fileprefix)
{

	// Create a 2D histogram comparing the neighbor-distances in GNGs with
	// four different parameterizations

	TCanvas *canvas = new TCanvas();

	gStyle->SetOptStat(0);

	TH2D *cHist = new TH2D("candleHist","distribution of distances between units",9,0,9,100,0,1.0);
	cHist->SetDirectory(0);

	//--------------------------------------------------------------------------

	{
		// open file
		TFile *f = TFile::Open(Form("%s_3D_25U.root",fileprefix));

		// read gng
		TGNG *gng = (TGNG*)f->Get("mygng");

		// fill in neighbor distances
		gng->FillNbDistanceDistribution(cHist,1.5);

		// set bin labels, we leave one column free between different gngs
		cHist->GetXaxis()->SetBinLabel(1,"");
		cHist->GetXaxis()->SetBinLabel(2,"3D_25U");

		// delete gng and close file
		delete gng;
		f->Close();
		delete f;
	}

	//--------------------------------------------------------------------------

	{
		// open file
		TFile *f = TFile::Open(Form("%s_3D_50U.root",fileprefix));

		// read gng
		TGNG *gng = (TGNG*)f->Get("mygng");

		// fill in neighbor distances
		gng->FillNbDistanceDistribution(cHist,3.5);

		// set bin labels, we leave one column free between different gngs
		cHist->GetXaxis()->SetBinLabel(3,"");
		cHist->GetXaxis()->SetBinLabel(4,"3D_50U");

		// delete gng and close file
		delete gng;
		f->Close();
		delete f;
	}

	//--------------------------------------------------------------------------

	{
		// open file
		TFile *f = TFile::Open(Form("%s_5D_25U.root",fileprefix));

		// read gng
		TGNG *gng = (TGNG*)f->Get("mygng");

		// fill in neighbor distances
		gng->FillNbDistanceDistribution(cHist,5.5);

		// set bin labels, we leave one column free between different gngs
		cHist->GetXaxis()->SetBinLabel(5,"");
		cHist->GetXaxis()->SetBinLabel(6,"5D_25U");

		// delete gng and close file
		delete gng;
		f->Close();
		delete f;
	}

	//--------------------------------------------------------------------------

	{
		// open file
		TFile *f = TFile::Open(Form("%s_5D_50U.root",fileprefix));

		// read gng
		TGNG *gng = (TGNG*)f->Get("mygng");

		// fill in neighbor distances
		gng->FillNbDistanceDistribution(cHist,7.5);

		// set bin labels, we leave one column free between different gngs
		cHist->GetXaxis()->SetBinLabel(7,"");
		cHist->GetXaxis()->SetBinLabel(8,"5D_50U");

		// delete gng and close file
		delete gng;
		f->Close();
		delete f;
	}

	// leave a last empty column
	cHist->GetXaxis()->SetBinLabel(9,"");

	// draw candle plot
	cHist->Draw("CANDLE");

	// save to pdf file
	canvas->Print(Form("%s_candle.pdf",fileprefix));	

}

