/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 
         International, see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.
--------------------------------------------------------------------------------

This is an example of how to run several trials, e.g., using different 
parameters.

Common usage in the ROOT command line would be, e.g.:

root [0] .x tgng_load.C
root [1] .L macros/basic_setup.C
root [2] init_gng(new TGNGVectorData(3), new TGNGVectorData(3), new TGNGMinkowskiDistance(2));

// you may want to resize the canvas to a more wider shape, e.g., in a ratio 3:1

root [3] .L randomtest.C
root [4] runbatch("output");

You should also have a look at analysetest.C for an example on how to read back 
the data generated by this macro.


*/

void runbatch(const char *fileprefix)
{

	{   // use a local scope so you do not have to worry about reintroducing variables

		gng->Init(new TGNGVectorData(3), new TGNGVectorData(3), new TGNGMinkowskiDistance(2));

		gng->SetMaxUnitCnt(25); // parameterize the gng

		testgng_rnd(1000000,3); // feed some inputs

		gng_can->Print(Form("%s_3D_25U.pdf",fileprefix)); // save visualization

		// create a new file and store the gng
		TFile *f = TFile::Open(Form("%s_3D_25U.root",fileprefix),"new"); 
		gng->Write();
		f->Close();
		delete f;
	}

	//--------------------------------------------------------------------------

	{

		gng->Init(new TGNGVectorData(5), new TGNGVectorData(5), new TGNGMinkowskiDistance(2));

		gng->SetMaxUnitCnt(25); // parameterize the gng

		testgng_rnd(1000000,5); // feed some inputs

		gng_can->Print(Form("%s_5D_25U.pdf",fileprefix)); // save visualization

		// create a new file and store the gng
		TFile *f = TFile::Open(Form("%s_5D_25U.root",fileprefix),"new"); 
		gng->Write();
		f->Close();
		delete f;
	}

	//--------------------------------------------------------------------------

	{   

		gng->Init(new TGNGVectorData(3), new TGNGVectorData(3), new TGNGMinkowskiDistance(2));

		gng->SetMaxUnitCnt(50); // parameterize the gng

		testgng_rnd(1000000,3); // feed some inputs

		gng_can->Print(Form("%s_3D_50U.pdf",fileprefix)); // save visualization

		// create a new file and store the gng
		TFile *f = TFile::Open(Form("%s_3D_50U.root",fileprefix),"new"); 
		gng->Write();
		f->Close();
		delete f;
	}

	//--------------------------------------------------------------------------

	{

		gng->Init(new TGNGVectorData(5), new TGNGVectorData(5), new TGNGMinkowskiDistance(2));

		gng->SetMaxUnitCnt(50); // parameterize the gng

		testgng_rnd(1000000,5); // feed some inputs

		gng_can->Print(Form("%s_5D_50U.pdf",fileprefix)); // save visualization

		// create a new file and store the gng
		TFile *f = TFile::Open(Form("%s_5D_50U.root",fileprefix),"new"); 
		gng->Write();
		f->Close();
		delete f;
	}

}
