#ifndef TNG_H
#define TNG_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of the main TNG class. See .cpp File for
more information.

*/

#include <TNamed.h>
#include <TObjArray.h>
#include <TMap.h>

#include "TGNGDataElement.h"
#include "TGNGDistanceMeasure.h"
#include "TNGUnit.h"
//#include "TGNGExtension.h"

class TNG : public TNamed 
{
	ClassDef(TNG,1);

/*
	Change log:

*/

public:
	enum ErrorCodes { ecNoInit, ecParamNull, ecNoBMU, ecNaN, ecNoMaxErr, ecIncomp, ecExtension, ecFatal };

	TNG();
	TNG(const char* name, const char* title);
	~TNG();

	void Init(Int_t size, TGNGDataElement *prototype, TGNGDistanceMeasure *distMeasure);

	TNGUnit* Feed(const TGNGDataElement *input); // learn input (element will not be owned)

	TNGUnit* Peek(const TGNGDataElement *input); // cluster input (element will not be owned)

	TGNGDistanceMeasure* GetDistanceMeasure();

	TObjArray fUnits; //|| units of the GNG

	ULong64_t GetInputCount();

	void RaiseError(UInt_t errorCode, const char* errMsg);

	void Print(Option_t* option = "") const;

	void SetEpsilon_start(Double_t val);
	void SetEpsilon_end(Double_t val);
	void SetLambda_start(Double_t val);
	void SetLambda_end(Double_t val);
	void SetRampTime(Double_t val);
	void SetRampTime2(Double_t val);

	Double_t GetEpsilon_start();
	Double_t GetEpsilon_end();
	Double_t GetLambda_start();
	Double_t GetLambda_end();
	Double_t GetRampTime();
	Double_t GetRampTime2();

	Double_t GetCurrentEpsilon();
	Double_t GetCurrentLambda();

private:
	void ResetNG();

	// parameters
	Double_t fEpsilon_start;  // adaptation at start
	Double_t fEpsilon_end;    // adaptation at end
	Double_t fLambda_start;   // neighborhood at start
	Double_t fLambda_end;     // neighborhood at end

	Double_t fRampTime; // duration from start to end
	Double_t fRampTime2; // duration from start to end

	Double_t fInpCnt; // input count

	TGNGDistanceMeasure *fDistMeasure; //|| distance measure used

	Bool_t fInitialized; // indicates wether or not the ng was initialized

	TObjArray fTmp; //! temporary storage to sort units by distance
};



#endif
