/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the definition of a cosine distance measure that can be
used with the gng.

*/
#include <TMath.h>

#include "../datatypes/TGNGVectorData.h"
#include "TGNGCosineDistance.h"

TGNGCosineDistance::TGNGCosineDistance() :
	TGNGDistanceMeasure()
{}

Double_t TGNGCosineDistance::GetDistance(const TGNGDataElement *a, const TGNGDataElement *b, TGNG*)
{
	const TGNGVectorData *av = dynamic_cast<const TGNGVectorData*>(a);
	const TGNGVectorData *bv = dynamic_cast<const TGNGVectorData*>(b);

	if ((av == 0) || (bv == 0)) 
		return TMath::QuietNaN();

	if (av->fVector.GetNrows() != bv->fVector.GetNrows())
		return TMath::QuietNaN();

	Double_t result = 0;
	Double_t aSqr   = 0;
	Double_t bSqr   = 0;
	Int_t nrOfRows = av->fVector.GetNrows();
	const double *avData = av->fVector.GetMatrixArray();
	const double *bvData = bv->fVector.GetMatrixArray();
	for (Int_t i = 0; i < nrOfRows; ++i) {
		result += avData[i] * bvData[i];
		aSqr   += TMath::Power(avData[i],2.0);
		bSqr   += TMath::Power(bvData[i],2.0);
	}
	if (aSqr > 0) aSqr = TMath::Sqrt(aSqr);
	if (bSqr > 0) bSqr = TMath::Sqrt(bSqr);
	aSqr *= bSqr;
	if (aSqr > 0) {
		result /= aSqr;
	} else {
		result = (aSqr == bSqr) ? 1 : -1;
	}

	return 1.0 - ((result + 1) / 2.0);
}

Bool_t TGNGCosineDistance::IsCompatible(const TGNGDataElement *a, TGNG*)
{
	return (dynamic_cast<const TGNGVectorData*>(a) != 0);
}

