#ifndef TGNGMINKOWSKIDISTANCE_H
#define TGNGMINKOWSKIDISTANCE_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of a minkowski distance that can be used
by the gng to determine the distance between two data elements of type 
TGNGVectorData with equal dimensions.

*/

#include "../core/TGNGDistanceMeasure.h"
#include "../core/TGNGDataElement.h"

class TGNGMinkowskiDistance : public TGNGDistanceMeasure 
{
	ClassDef(TGNGMinkowskiDistance,2);

public:
	enum LinkageType { ltSingle, ltComplete, ltAverage };
	enum RecursiveMode { rmPeek, rmFeed };

	TGNGMinkowskiDistance();
	TGNGMinkowskiDistance(Double_t p, 
      TGNGMinkowskiDistance::LinkageType lt = TGNGMinkowskiDistance::ltSingle,
      TGNGMinkowskiDistance::RecursiveMode rm = TGNGMinkowskiDistance::rmPeek);
	
	Double_t GetDistance(const TGNGDataElement *a, const TGNGDataElement *b, TGNG *gng);
	
	Double_t GetApproxDistance(const TGNGDataElement *a, const TGNGDataElement *b, TGNG *gng);

	Bool_t IsCompatible(const TGNGDataElement *a, TGNG *gng);

	void SetP(Double_t p);
	Double_t GetP();

	void SetLinkageType(TGNGMinkowskiDistance::LinkageType lt);
	TGNGMinkowskiDistance::LinkageType GetLinkageType();

	void SetRecursiveMode(TGNGMinkowskiDistance::RecursiveMode rm);
	TGNGMinkowskiDistance::RecursiveMode GetRecursiveMode();

private:

	Double_t fP; // exponent used in the minkowski distance

	LinkageType fLT; // linkage type used in recursive context

	RecursiveMode fRM; // recursive mode to use for measuring distance in TGNGRecursiveData

};



#endif


