#ifndef TGNGHIERARCHICALCLUSTEREXT_H
#define TGNGHIERARCHICALCLUSTEREXT_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of a hierarchical clustering extension
supporting single, complete, and average linkage as well as using the distance
measure provided by the gng or using the average bin error of local input space
histograms as distance.
*/

#include <TObjString.h>
#include <TObjArray.h>

#include "../../core/TGNGExtension.h"
#include "TGNGHcNode.h"

class TGNGHierarchicalClusterExt : public TGNGExtension
{
	ClassDef(TGNGHierarchicalClusterExt,2);

	// v2: reflecting changes in TGNGExtension

public:
	enum DistanceType { dtDefault, dtLISH };
	enum LinkageType { ltSingle, ltComplete, ltAverage };

	TGNGHierarchicalClusterExt();

	void OnGNGReset(TGNG *gng);

	void OnFeedResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist,
				      TGNGUnit *bmu2, Double_t bmu2Dist, const TGNGDataElement *input);

	void OnNewUnit(TGNG *gng, TGNGUnit *newUnit);

	void SetInterval(Int_t interval);

	TGNGHcNode* GetRoot();

	void SetDistanceType(Int_t dType);
	void SetLinkageType(Int_t lType);

private:

	TObjString fAttrKey; // key for the unit attribute "HCEXT"

	Int_t fInterval; // interval when to perform clustering
	Int_t fInpCnt;   // number of inputs so far

	TObjArray fTopLevel; //|| memory for storing top level nodes

	Int_t fDistanceType; // sets the distance type used for distances between units
	Int_t fLinkageType; // sets the linkage used to determine cluster distance

};



#endif


