#ifndef TGNGSIMPLECLUSTEREXT_H
#define TGNGSIMPLECLUSTEREXT_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of a simple clustering approach that uses
the average bin error of the local input space histograms to determine, if an
edge in the gng should be traversed, i.e., if the gng units connected by this
edge should belong to the same cluster.
*/

#include <vector>

#include <TObjString.h>

#include "../../core/TGNGExtension.h"

class TGNGClusterInfo : public TObject
{
	ClassDef(TGNGClusterInfo,1);

public:
	TGNGClusterInfo() : 
		TObject(),
		fClusterID(-1),
		fClusterColor(kGray+2),
		fClusterTextColor(kBlack)
	{}

	TGNGClusterInfo(Int_t id, Color_t color) : 
		TObject(),
		fClusterID(id),
		fClusterColor(color)
	{}

	Int_t   fClusterID;
	Color_t fClusterColor;
	Color_t fClusterTextColor;
};


class TGNGSimpleClusterExt : public TGNGExtension
{
	ClassDef(TGNGSimpleClusterExt,2);

	// v2: reflecting changes in TGNGExtension

public:

	TGNGSimpleClusterExt();

	void OnGNGReset(TGNG *gng);

	void OnFeedResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist, 
					  TGNGUnit *bmu2, Double_t bmu2Dist, const TGNGDataElement *input);

	void OnNewUnit(TGNG *gng, TGNGUnit *newUnit);

	void SetLishWeightCenter(Double_t center);
	void SetLishWeightSteepness(Double_t steepness);

	void SetClusterThres(Double_t thres);

	void SetInterval(Int_t interval);

private:
	void InitColors();

	TObjString fAttrKey;

	std::vector<Color_t> fColors; //|| color table of available cluster colors
	std::vector<Color_t> fTextColors; //|| color table of available cluster colors
	Color_t fOutlierColor; // color of outliers
	Color_t fUnprocessedColor; // color of units not processed so far

	Int_t fNextFreeID; // next free cluster ID

	Int_t fInterval; // interval when to perform clustering
	Int_t fInpCnt;   // number of inputs so far

	Double_t fLishWeightCenter;    // center of slope on generalized logistic function
	Double_t fLishWeightSteepness; // steepness of slope on generalized logistic function

	Double_t fClusterThres; // simple threshold for weighted average lish bin error
};



#endif


