#ifndef TGNGLISHEXT_H
#define TGNGLISHEXT_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of the local input space histogram extension.
Register this extension with a gng to enable local input space histograms for
the particular gng.

You can use the static functions GetAvgBinErrorDist() and FillAvgBinErrorDist()
to analyse the LISH histograms present in a gng.
*/

#include <TObjString.h>
#include <TH1D.h>

#include "../../core/TGNGExtension.h"

class TGNGLishExt : public TGNGExtension 
{
	ClassDef(TGNGLishExt,3);

public:

	TGNGLishExt();
	explicit TGNGLishExt(UInt_t ls);

	void OnNewEdge(TGNG *gng, TGNGEdge *newEdge);	

	void OnUnitUpdate(TGNG                  *gng, 
	                  TGNGUnit              *bmu,
	                  Double_t               bmuDist,
	                  TGNGUnit              *bmu2,
	                  Double_t               bmu2Dist,
	                  TGNGEdge              *bmuEdge,
	                  const TGNGDataElement *input    );

	static TH1D* GetAvgBinErrorDist(TGNG *gng);
	static void FillAvgBinErrorDist(TGNG *gng, TH2D* hist, Double_t xVal);

private:
	TObjString fAttrKey; // attribute key to store the LISH data in the attribute map of each edge

	UInt_t fLishSize; // size of the lish

};



#endif


