#ifndef TGNGINPUTLOGEXT_H
#define TGNGINPUTLOGEXT_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of a input logging extension that stores
either the last n, best n, or worst n inputs to a gng unit as an unit attribute.

The logging mode can be set by SetLogMode() to the values lmLastN, lmBestN, lmWorstN.
The log size n per unit can be set by SetLogSize()
*/

#include <TObjString.h>

#include "../../core/TGNGExtension.h"


class TGNGInputLogExt : public TGNGExtension
{
	ClassDef(TGNGInputLogExt,2);

	// v2: reflect changes in TGNGExtension

public:
	enum LogMode { lmLastN, lmBestN, lmWorstN };

	TGNGInputLogExt();
	TGNGInputLogExt(Int_t mode, Int_t size, const char *postfix = "");

	void OnGNGReset(TGNG *gng);

	void OnNewUnit(TGNG *gng, TGNGUnit *newUnit);

	void OnPeekResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist,
					  TGNGUnit *bmu2, Double_t bmu2Dist, const TGNGDataElement *input);
	void OnFeedResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist,
					  TGNGUnit *bmu2, Double_t bmu2Dist, const TGNGDataElement *input);

	void  SetLogMode(Int_t mode);
	Int_t GetLogMode();

	void  SetLogSize(Int_t size);
	Int_t GetLogSize();

	void SetFeedLog(Bool_t enable);
	void SetPeekLog(Bool_t enable);

private:
	void LogInput(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist, const TGNGDataElement *input);

	TObjString fAttrKey; // contains the string "INPLOG" + postfix

	Int_t fLogMode; // the log mode used
	Int_t fLogSize; // size of the log per unit

	Bool_t fFeedEnable; // if true, feed events are logged (default: false)
	Bool_t fPeekEnable; // if true, peek events are logged (default: true)
};



#endif


