/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the definition of a logging extension that stores the 
attributes of GNGs that are the prototypes of the current gng. Thus it is used
in an RGNG. The logfile is typically shared with a FullLogger Extension.
*/

#include <TFile.h>
#include <TTree.h>

#include "../../core/TGNGUnit.h"
#include "../../core/TGNG.h"
#include "../../core/TGNGDataElement.h"
#include "../../datatypes/TGNGRecursiveData.h"
#include "../../extensions/functional/TGNGActivityExt.h"

#include "TGNGRecLogExt.h"

TGNGRecLogExt::TGNGRecLogExt() : 
	TGNGExtension(),
	fLogFile(0),
	fAttribTree(0),
	fInpCnt(0),
	fUnitIdx(0),
	fAttributes(0),
	fRatio(0),
	fDist1(0),
	fDist2(0),
	fActId("ACTIVITY")
{
}

TGNGRecLogExt::TGNGRecLogExt(TFile *logfile) : 
	TGNGExtension(),
	fLogFile(logfile),
	fAttribTree(0),
	fInpCnt(0),
	fUnitIdx(0),
	fAttributes(0),
	fRatio(0),
	fDist1(0),
	fDist2(0),
	fActId("ACTIVITY")
{
	fLogFile->cd();

	fAttribTree = new TTree("attribTree","gng attributes of prototypes");
	fAttribTree->Branch("inputCnt",&fInpCnt,"idx/l");
	fAttribTree->Branch("unitIdx",&fUnitIdx,"uidx/I");
	fAttribTree->Branch("attributes","TMap",&fAttributes,32000,0);
	fAttribTree->SetMaxTreeSize(5000000000000LL);

	fActivityTree = new TTree("activityTree","activity of prototypes");
	fActivityTree->Branch("inputCnt",&fInpCnt,"idx/l");
	fActivityTree->Branch("unitIdx",&fUnitIdx,"uidx/I");
	fActivityTree->Branch("ratio",&fRatio,"ratio/D");
	fActivityTree->Branch("dist1",&fDist1,"dist1/D");
	fActivityTree->Branch("dist2",&fDist2,"dist2/D");
	fActivityTree->SetMaxTreeSize(5000000000000LL);
}

TGNGRecLogExt::~TGNGRecLogExt()
{
}

void TGNGRecLogExt::OnGNGReset(TGNG *gng)
{
	if (fLogFile == 0)
		return;

	if (fAttribTree == 0)
		return;

	if (fActivityTree == 0)
		return;

	fLogFile->cd();

	fAttribTree->Write();
	delete fAttribTree;
	fAttribTree = 0;

	fActivityTree->Write();
	delete fActivityTree;
	fActivityTree = 0;

}

void TGNGRecLogExt::OnPeekResult(TGNG *gng, TGNGUnit*, Double_t, TGNGUnit*, 
	                             Double_t, const TGNGDataElement*)
{
	LogAttributes(gng);
}

void TGNGRecLogExt::OnFeedResult(TGNG *gng, TGNGUnit*, Double_t, TGNGUnit*, 
	                             Double_t, const TGNGDataElement*)
{
	LogAttributes(gng);
}

void TGNGRecLogExt::LogAttributes(TGNG *gng)
{
	if (fAttribTree == 0)
		return;

	fInpCnt = gng->GetInputCount();

	Int_t nrOfUnits = gng->fUnits.GetEntriesFast();
	for (Int_t i = 0; i < nrOfUnits; ++i) {
		fUnitIdx = i;

		TGNGUnit *curUnit = static_cast<TGNGUnit*>(gng->fUnits.At(i));

		TGNGRecursiveData *recData = dynamic_cast<TGNGRecursiveData*>(curUnit->fPrototype);

		if (recData == 0)
			continue;

		fAttributes = &(recData->fGNG.fAttributes);

		fAttribTree->Fill();

		TGNGActivity *act = static_cast<TGNGActivity*>(fAttributes->GetValue(&fActId));
		if (act != 0) {
			fRatio = act->a1;
			fDist1 = act->d1;
			fDist2 = act->d2;
		}

		fActivityTree->Fill();

	}
}

