#ifndef TGNGFRUREVIS_H
#define TGNGFRUREVIS_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of a gng graph visualization that uses a
force-directed graph drawing approach based the work of Fruchterman and 
Reingold.

See Draw() method for options.
*/

#include <vector>

#include <TVirtualPad.h>
#include <TTimeStamp.h>
#include <TAttLine.h>
#include <TAttMarker.h>
#include <TAttText.h>
#include <TAttFill.h>
#include <TObjString.h>

#include "../../core/TGNGExtension.h"

class TGNGFruReVis : public TGNGExtension, public TAttLine, public TAttMarker, public TAttText, public TAttFill
{
	ClassDef(TGNGFruReVis,3);

	// v3: reflecting changes in TGNGExtension

public:

	TGNGFruReVis();

	void Draw(Option_t* option = "");
	void Paint(Option_t *option);

	// virtual methods
	void OnPeekResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist, TGNGUnit*, Double_t, const TGNGDataElement *input);
	void OnFeedResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist, TGNGUnit*, Double_t, const TGNGDataElement *input);
	void OnNewUnit(TGNG *gng, TGNGUnit *newUnit);

	void SetUpdateInterval(Double_t sec);
	void SetIterations(Int_t iter);

	void SetEdgeColor(Color_t color);
	void SetEdgeStyle(Style_t style);
	void SetEdgeWidth(Width_t width);

	void SetUnitColor(Color_t color);
	void SetUnitSize(Size_t	size);
	void SetUnitStyle(Style_t style);

	void SetUnitTextColor(Color_t  color);
	void SetUnitTextFont(Font_t	 font);
	void SetUnitTextSize(Float_t size);

	void SetLishWeighting(Bool_t enable);

	void SetLishWeightCenter(Double_t center);
	void SetLishWeightSteepness(Double_t steepness);

	void SetPalette(Int_t a, Bool_t invert);

	void SetLocalSpace(Double_t localSpace);

private:
	void UpdateVis();

	void addPos(TGNG *gng, TGNGUnit *newUnit, Bool_t forceRnd = kFALSE);

	Double_t GetEdgeLishStrength(TH1D *hist);

	TObjString fPosAttr;  // attribute key for position information
	TObjString fPadAttr;  // attribute key for position information

	Int_t fIterations; // iterations used for the Eades algorithm
	Double_t fTemp;    // temperature to cool things down if no new units are added

	TVirtualPad *fCurrentPad; //! stores current pad we are drawn to

	Double_t   fUpdateInterval; // update interval
	TTimeStamp fLastUpdate;     // last time the view was painted

	TGNG     *fCurrentGNG; //! stores current gng provided OnFeedResult/OnPeekResult
	TGNGUnit *fCurrentBMU; //! stores current unit provided OnFeedResult/OnPeekResult

	Color_t	fEdgeColor; // color used for edges
	Style_t	fEdgeStyle; // style used for edges
	Width_t	fEdgeWidth; // width used for edges

	Color_t	fUnitColor; // color used for units
	Size_t	fUnitSize;  // size used for units
	Style_t	fUnitStyle;	// marker style used for units

	Color_t	fUnitMColor; // color used for units that are marked
	Size_t	fUnitMSize;  // size used for units that are marked
	Style_t	fUnitMStyle; // marker style used for units that are marked

	Color_t  fUnitTextColor;   // unit text color
	Font_t	 fUnitTextFont;    // unit text font
	Float_t	 fUnitTextSize;    // unit text size

	Bool_t fLishWeight; // forces will be weighted by the average bin error in the edges LISH

	Double_t fLishWeightCenter;    // center of slope on generalized logistic function
	Double_t fLishWeightSteepness; // steepness of slope on generalized logistic function

	TObjArray fVisEdges; //! temporary storage to sort edges by strength

	Int_t fPaletteA; // id of first palette

	std::vector<Color_t> fPalA; //! colors of first palette

	Double_t fLocalSpace; // space around each unit which repells a lot 

};



#endif



