#ifndef TGNGHICLUSTERVIS_H
#define TGNGHICLUSTERVIS_H

/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the declaration of a hierarchical clustering visualization
based on simple dendrograms. It uses the hierarchical clustering generated by
TGNGHierarchicalClusterExt.
*/


#include <vector>

#include <TVirtualPad.h>
#include <TTimeStamp.h>
#include <TAttLine.h>
#include <TAttMarker.h>
#include <TAttText.h>
#include <TAttFill.h>
#include <TObjString.h>

#include "../../core/TGNGExtension.h"

class TGNGHiClusterVis : public TGNGExtension, public TAttLine, public TAttMarker, public TAttText, public TAttFill
{
	ClassDef(TGNGHiClusterVis,2);

	// v2: reflecting changes in TGNGExtension

public:

	TGNGHiClusterVis();

	void Draw(Option_t* option = "");
	void Paint(Option_t *option);

	// virtual methods
	void OnPeekResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist, TGNGUnit*, Double_t, const TGNGDataElement *input);
	void OnFeedResult(TGNG *gng, TGNGUnit *bmu, Double_t bmuDist, TGNGUnit*, Double_t, const TGNGDataElement *input);

	void OnGNGReset(TGNG *gng);

	void SetUpdateInterval(Double_t sec);

	void SetEdgeColor(Color_t color);
	void SetEdgeStyle(Style_t style);
	void SetEdgeWidth(Width_t width);

	void SetTableTextTopOffsetX(Double_t ox);
	void SetTableTextTopOffsetY(Double_t oy);
	void SetTableTextColor(Color_t color);
	void SetTableTextFont(Font_t font);
	void SetTableTextSize(Float_t size);

private:
	void UpdateVis();

	TVirtualPad *fCurrentPad; //! stores current pad we are drawn to

	Double_t   fUpdateInterval; // update interval
	TTimeStamp fLastUpdate;     // last time the view was painted

	TGNG     *fCurrentGNG; //! stores current gng provided OnFeedResult/OnPeekResult
	TGNGUnit *fCurrentBMU; //! stores current unit provided OnFeedResult/OnPeekResult
	TGNGHierarchicalClusterExt *fCurrentHC; //! stores the current hc extension

	Color_t	fEdgeColor; // color used for edges
	Style_t	fEdgeStyle; // style used for edges
	Width_t	fEdgeWidth; // width used for edges

	Double_t fTableTextTopOffsetX; // unit text x offset from center
	Double_t fTableTextTopOffsetY; // unit text y offset from center
	Color_t  fTableTextColor;   // unit text color
	Font_t	 fTableTextFont;    // unit text font
	Float_t	 fTableTextSize;    // unit text size

	TObjArray fCandidates; //! temporary storage

};



#endif



