/*
FernUniversität in Hagen, Lehrgebiet Mensch-Computer-Interaktion
License: Creative Commons Attribution-Noncommercial-Share Alike 4.0 International, 
         see README file that comes with this work
Author: J. Kerdels

The use of this code for military and/or intelligence purposes is disapproved of.

This file contains the definition of the TGNGVisEdge class. It stores 
edge-information used by the TGNGFruReVis visualization.
*/
#include "TGNGVisEdge.h"

TGNGVisEdge::TGNGVisEdge() :
	TObject(),
	fStrength(0),
	fX1(0),
	fY1(0),
	fX2(0),
	fY2(0),
	fFlag(0)
{
}

TGNGVisEdge::TGNGVisEdge(Double_t strength, Double_t x1, Double_t y1, Double_t x2, Double_t y2) :
	TObject(),
	fStrength(strength),
	fX1(x1),
	fY1(y1),
	fX2(x2),
	fY2(y2),
	fFlag(0)
{
}

Bool_t TGNGVisEdge::IsEqual(const TObject* obj) const
{
	// two edges are equal if the coordinates of their start and end points as
    // well as their strengths are equal.

	const TGNGVisEdge *other = static_cast<const TGNGVisEdge*>(obj);
	return (fStrength == other->fStrength) &&
	       (fX1 == other->fX1) && (fY1 == other->fY1) &&
	       (fX2 == other->fX2) && (fY2 == other->fY2);
}

Bool_t TGNGVisEdge::IsSortable() const
{
	// edges are sortable

	return kTRUE;
}

Int_t TGNGVisEdge::Compare(const TObject* obj) const
{
	// edges are sorted by their strength

	const TGNGVisEdge *other = static_cast<const TGNGVisEdge*>(obj);
	return (fStrength < other->fStrength) ? -1 : ((fStrength > other->fStrength) ? 1 : 0);
}
